# -*-coding:utf-8 -*- #
# ---------------------------------------------------------------------------
# ProjectName:   Python_learn
# FileName:      read_excel.py
# Author:       xxxxxxx
# Datetime:     2023-08-07 19:38
# Description:
# 
# ---------------------------------------------------------------------------
import openpyxl

from learn.example0807.common.read_ini import ReadIni
from learn.example0807.common.read_json import read_json


class ReadExcel:
    def __init__(self):
        self.read_ini = ReadIni()
        case_data_path = self.read_ini.get_filepath("case")
        expect_data_path = self.read_ini.get_filepath("except")
        sql_data_path = self.read_ini.get_filepath("sql")
        self.case_data_dict = read_json(case_data_path)
        self.expect_data_dict = read_json(expect_data_path)
        self.sql_data_dict = read_json(sql_data_path)


        self.excel_name = self.read_ini.get_filepath("excel")
        self.table_name = self.read_ini.get_tablepath("table_name")
        wb =openpyxl.load_workbook(self.excel_name)
        self.ws = wb[self.table_name]

    def module_name(self,row):
        return self.ws["B"+str(row)].value.strip()
    def interface_name(self,row):
        return self.ws["C"+str(row)].value.strip()
    def case_title(self,row):
        return self.ws["D"+str(row)].value.strip()
    def case_level(self,row):
        return self.ws["E"+str(row)].value.strip()
    def request_method(self,row):
        return self.ws["F"+str(row)].value.strip().lower()
    def case_url(self,row):
        host =self.read_ini.get_hostpath("test_bpm")
        result = self.ws["G"+str(row)].value.strip().lower()
        return host+result
    def mime(self,row):
        result = self.ws["H" + str(row)].value
        if result is None:
            return None
        elif result.strip():
            return result.strip().lower()
    def case_data(self,row):
        result = self.ws["I" + str(row)].value
        moudle_name = self.module_name(row)
        interface_name = self.interface_name(row)
        if result is None:
            return None
        elif result.strip():
            return self.case_data_dict[moudle_name][interface_name][result]
    def except_data(self,row):
        result = self.ws["J" + str(row)].value
        moudle_name = self.module_name(row)
        interface_name = self.interface_name(row)
        if result is None:
            return None
        elif result.strip():
            return self.expect_data_dict[moudle_name][interface_name][result]
    def sql_type(self,row):
        result = self.ws["K" + str(row)].value
        if result:
            return result.strip().lower()
    def sql_sentence(self,row):
        result = self.ws["L"+str(row)].value
        moudle_name = self.module_name(row)
        interface_name = self.interface_name(row)
        if result is None:
            return None
        elif result.strip():
            return self.sql_data_dict[moudle_name][interface_name][result]
    def updata_key(self,row):
        return self.ws["M"+str(row)].value

    def get_data(self):
        list_data = []
        for row in range(2, self.ws.max_row + 1):
            module = self.module_name(row)
            interface = self.interface_name(row)
            title = self.case_title(row)
            level = self.case_level(row)
            request_method = self.request_method(row)
            case_url = self.case_url(row)
            mime = self.mime(row)
            case_data = self.case_data(row)
            except_data = self.except_data(row)
            sql_type = self.sql_type(row)
            sql_sentence = self.sql_sentence(row)
            updata_key = self.updata_key(row)
            list_data.append([module,interface,title,level,request_method,case_url,mime,case_data,except_data,sql_type,sql_sentence,updata_key])
        else:
            return list_data

if __name__ == '__main__':
    read_excel =ReadExcel()
    print(read_excel.get_data())